#
# spec file for package apache-commons-net
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global base_name    net
%global short_name   commons-%{base_name}
%bcond_with tests
Name:           apache-%{short_name}
Version:        3.9.0
Release:        2.2
Summary:        Internet protocol suite Java library
License:        Apache-2.0
Group:          Development/Libraries/Java
URL:            http://commons.apache.org/%{base_name}/
Source0:        https://archive.apache.org/dist/commons/%{base_name}/source/%{short_name}-%{version}-src.tar.gz
Source1:        %{name}-build.xml
BuildRequires:  ant
BuildRequires:  fdupes
BuildRequires:  java-devel >= 1.8
BuildRequires:  javapackages-local >= 6
Provides:       %{short_name} = %{version}-%{release}
Obsoletes:      %{short_name} < %{version}-%{release}
Provides:       jakarta-%{short_name} = %{version}-%{release}
Obsoletes:      jakarta-%{short_name} < %{version}-%{release}
BuildArch:      noarch
%if %{with tests}
BuildRequires:  ant-junit
%endif

%description
This is an Internet protocol suite Java library originally developed by
ORO, Inc.  This version supports Finger, Whois, TFTP, Telnet, POP3, FTP,
NNTP, SMTP, and some miscellaneous protocols like Time and Echo as well
as BSD R command support. The purpose of the library is to provide
fundamental protocol access, not higher-level abstractions.

%package javadoc
Summary:        API documentation for %{name}
Group:          Documentation/HTML

%description javadoc
%{summary}.

%prep
%setup -q -n %{short_name}-%{version}-src
cp %{SOURCE1} build.xml

%build
ant \
%if %{without tests}
  -Dtest.skip=true \
%endif
  jar javadoc

%install
# pom
install -dm 0755 %{buildroot}%{_javadir}
install -pm 0644 target/%{short_name}-%{version}.jar %{buildroot}%{_javadir}/%{short_name}.jar
ln -sf %{short_name}.jar %{buildroot}%{_javadir}/%{name}.jar
# pom
install -dm 0755 %{buildroot}%{_mavenpomdir}
%{mvn_install_pom} pom.xml %{buildroot}%{_mavenpomdir}/%{short_name}.pom
%add_maven_depmap %{short_name}.pom %{short_name}.jar
# javadoc
install -dm 0755 %{buildroot}%{_javadocdir}/%{name}
cp -pr target/site/apidocs/* %{buildroot}%{_javadocdir}/%{name}/
%fdupes -s %{buildroot}%{_javadocdir}

%files -f .mfiles
%doc README.md RELEASE-NOTES.txt
%license LICENSE.txt NOTICE.txt
%{_javadir}/%{name}.jar

%files javadoc
%license LICENSE.txt NOTICE.txt
%{_javadocdir}/%{name}

%changelog
* Wed Oct  2 2024 Fridrich Strba <fstrba@suse.com>
- Spec file cleanup
* Mon Dec  5 2022 Fridrich Štrba <fridrich.strba@bluewin.ch>
- Upgrade to 3.9.0 (Security fixes)
  * Changes in 3.9.0
    + Use yyyy instead of YYYY in SimpleDateFormat #97.
    Fixes NET-708.
    + Prevent serialization of the 4 classes that implement
    Serializable. It is not useful and is unlikely to work
    properly.
    + Use Math.min and Math.max method instead of manual
    calculations. #104.
    + Add FTP option to toggle use of return host like CURL.
    Fixes NET-711, bsc#1206018, CVE-2021-37533.
    + FTPSClient execPROT removes proxy settings #90. Fixes NET-642.
    + JUnit5 assertThrows SimpleSMTPHeaderTestCase #121.
    + JUnit5 assertThrows TestTimeInfo #120.
    + Simplify conditions avoiding extra operations #88.
    + Remove reflection from SSLSocketUtils.
    + Process files with spaces in name for OS400 #95.
    Fixes NET-707.
    + [FTP] Add FTPClient.mdtmInstant(String).
    + [FTP] Add MLSxEntryParser.parseGmtInstant(String).
    + [FTP] Add FTPClient.getControlKeepAliveReplyTimeoutDuration().
    + [FTP] Add FTPClient.setControlKeepAliveReplyTimeout(Duration).
    + [FTP] Add FTPClient.getControlKeepAliveTimeoutDuration().
    + [FTP] Add FTPClient.setControlKeepAliveTimeout(Duration).
    + [FTP] Add FTPClient.getDataTimeout().
    + [FTP] Add FTPClient.setDataTimeout(Duration).
    + [FTP] Add FTPFile.getTimestampInstant().
  * Changes in 3.8.0
    + Add and use NetConstants.
    + Add and use SocketClient.applySocketAttributes().
    + [FTP] Add FTPClient.hasFeature(FTPCmd).
    + [FTP] Add FTPClient.mdtmCalendar(String).
    + [IMAP] Fix concurrent counting of chunks in IMAPExportMbox.
    + Fix possible if rare NPEs in tests.
    + Update SocketClient default connect timeout from ∞ to 60
    seconds #51. Fixes NET-685.
    + Apply SocketClient timeout after connection but before SSL
    negotiation. Fixes NET-695.
    + Minor Improvements #71, #72.
  * Changes in 3.7.2
    + Host name is not set on the SSLSocket causing
    isEndpointCheckingEnabled to fail. Fixes NET-689.
    + Fix possible socket and input stream leak on socket exception
    in org.apache.commons.net.ftp.FTPClient._retrieveFile(String,
    String, OutputStream).
    + Performance issue when using the FTPClient to retrieve
    files #65. Fixes NET-690.
    + Improve Javadoc for IMAPSClient #68. Fixes NET-691.
  * Changes in 3.7.1
    + [FTPS] javax.net.ssl.SSLException: Unsupported or unrecognized
    SSL message, #59. Fixes NET-687.
  * Changes in 3.7
    + IMAPClient.APPEND does not always calculate the correct
    length. Fixes NET-673.
    + ALLO FTP Command for files >2GB. Fixes NET-646.
    + IMAPClient could simplify using empty arguments. Fixes
    NET-615.
    + IMAP fails to quote/encode mailbox names. Fixes NET-614.
    + NPE when closing telnet stream. Fixes NET-643.
    + Add Automatic-Module-Name MANIFEST entry for Java 9
    compatibility. Fixes NET-648.
    + SubnetUtils.SubnetInfo.isInRange("0.0.0.0") returns true for
    CIDR/31, 32. Fixes NET-641.
    + Telnet subnegotiations hard-limited to 512 bytes - allow
    override. Fixes NET-638.
    + MVSFTPEntryParser.preParse - MVS, z/OS - allow for merged
    Ext/Used fields. Fixes NET-639.
    + examples should be in org.apache.commons.net subpackage. Fixes
    NET-636.
    + Add SIZE command support. Fixes NET-634.
    + Add POP3ExportMbox example code
    + Add XOAUTH2 to IMAP and SMTP. Fixes NET-633.
    + FTPHTTPClient - support for encoding other than UTF-8. Fixes
    NET-632.
    + Bug in MVSFTPEntryParser.parseUnixList (FindBugs). Fixes
    NET-631.
    + Error when using org.apache.commons.net.ftp.FTPClient
    setControlKeepAliveTimeout. Fixes NET-584.
    + SubnetUtils#SubnetUtils - improved comment. Fixes NET-626.
    + SubnetUtils - improve construction. Fixes NET-625.
    + SubnetInfo#getCidrSignature - improve functions. Fixes
    NET-624.
    + SubnetInfo#toCidrNotation: A wrong format subnet mask is
    allowed. Fixes NET-624.
    + SubnetUtils - fixed spelling errors. Fixes NET-623.
    + SubnetUtils#SubnetInfo - remove unnecessary accessors. Fixes
    NET-621.
    + SubnetUtils - improve binary netmask algorithm. Fixes NET-619.
    + System Information Leak in ftp parser. Fixes NET-613.
    + VMS ftp LIST parsing results in empty file list. Fixes
    NET-678.
    + FTPListParseEngine should support listing via MLSD. Fixes
    NET-674.
    + NullPointerException when FTPClient remote verification fails.
    Fixes NET-663.
    + 227 Entering Passive Mode. Fixes NET-649.
    + Next and Previous IP Address in SubnetUtils.SubnetInfo. Fixes
    NET-660.
    + MVSFTPEntryParser doesn't support Record Formats of U. Fixes
    NET-682.
* Fri Mar 18 2022 Fridrich Strba <fstrba@suse.com>
- Build with source/target levels 8
* Thu Jan  9 2020 Fridrich Strba <fstrba@suse.com>
- Remove reference to the parent pom, since we don't build with
  maven
* Sat Mar  2 2019 Fridrich Strba <fstrba@suse.com>
- Rename to apache-commons-net
- Upgrade to version 3.6
- Generate and customize the ant build file
* Fri Sep  8 2017 fstrba@suse.com
- Specify java source and target 1.6 in order to allow building
  with jdk9
* Fri Jun  9 2017 tchvatal@suse.com
- Require java 1.6 or newer to build
* Fri May 19 2017 tchvatal@suse.com
- Fix build with new javapackages-tools
* Wed Mar 18 2015 tchvatal@suse.com
- Fix build with new javapackages-tools
* Tue Jul  8 2014 tchvatal@suse.com
- Fix sle build properly.
* Wed Apr 30 2014 darin@darins.net
- Update project_xml patch for strict fuzz
- Suppress bytecode check on SLES
- remove java-javadoc build requirement
* Mon Sep  9 2013 tchvatal@suse.com
- Move from jpackage-utils to javapackage-tools
* Fri Sep  6 2013 mvyskocil@suse.com
- use add_maven_depmap
* Thu Nov 29 2012 mvyskocil@suse.com
- buildrequire saxon8 (bnc#780666)
- remove self-obsolete commons-net
* Wed Nov 28 2012 mvyskocil@suse.com
- require saxon9 for build
- don't build with java5 target
* Tue Jun 26 2012 mvyskocil@suse.cz
- remove openjdk6 dependency
* Mon Mar 12 2012 mvyskocil@suse.cz
- fix bnc#749895 - ant FTP action fails on the date with leap year
* Tue Apr 28 2009 mvyskocil@suse.cz
- Initial SUSE packaging (version 1.4.1 from jpp5)
